#
# The MIT License (MIT)
#
# Copyright (c) 2015 Dmitry Sovetov
#
# https://github.com/dmsovetov
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

import os

# class File
class File:
	# ctor
	def __init__( self, target, folder, fileName ):
		self._target    = target
		self._folder    = folder
		self._fileName  = fileName

	# sourcePath
	@property
	def sourcePath( self ):
		return os.path.join( self._folder.sourcePath, self._fileName )

	# fullPath
	@property
	def fullPath( self ):
		return os.path.abspath( os.path.join( self._target.sourcePath, self.sourcePath ) )

	# sourceFolder
	@property
	def sourceFolder( self ):
		return self._folder.sourcePath

	# fileName
	@property
	def fileName( self ):
		return os.path.basename( self.localPath )

	# name
	@property
	def name( self ):
		return self.nameAndExtension[0]

	# ext
	@property
	def ext( self ):
		return self.nameAndExtension[1]

	# nameAndExtension
	@property
	def nameAndExtension( self ):
		return os.path.splitext( self.fileName )

	# relativePath
	def relativePath( self, base ):
		return os.path.join( os.path.relpath( self._target.sourcePath, base ), self.localPath )


#################################################################################
#
# The MIT License (MIT)
#
# Copyright (c) 2015 Dmitry Sovetov
#
# https://github.com/dmsovetov
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#################################################################################

import os

from Xcode5 	import Xcode5
from ..Template import Template

# class MacOS
class MacOS( Xcode5 ):
	# ctor
	def __init__( self ):
		Xcode5.__init__( self )

	# getPlatformId
	def getPlatformId( self ):
		return 'osx'


	# getProjectSettings
	def getProjectSettings( self ):
		if not self.makefile.get( 'SDK' ):
			self.makefile.set( 'SDK', Xcode5.listAvailableSDKs( 'MacOSX' )[0] )

		return {
			'Debug': {
				'ARCHS':                        'i386',
				'SDKROOT':                      self.makefile.get( 'SDK' ),
			    'ALWAYS_SEARCH_USER_PATHS':     'NO',
			},
		    'Release': {
				'ARCHS':                        'i386',
				'SDKROOT':                      self.makefile.get( 'SDK' ),
			    'ALWAYS_SEARCH_USER_PATHS':     'NO',
		    }
		}


#################################################################################
#
# The MIT License (MIT)
#
# Copyright (c) 2015 Dmitry Sovetov
#
# https://github.com/dmsovetov
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#################################################################################

from Resource       import Resource
from ObjectList     import ObjectList
from ...Template    import Template

# class BuildPhase
class BuildPhase( Resource ):
	# ctor
	def __init__( self, isa, target, name ):
		Resource.__init__( self, isa, name )

		self.target = target
		self.isa    = isa
		self.files  = ObjectList()

	# add
	def add( self, item ):
		self.files.add( item )

	# compile
	def compile( self ):
		return Template( SourceBuildPhase.Root ).compile( { 'id': self.id, 'isa': self.isa, 'target': self.target.name, 'files': self.files.compileList() } )

	# Root
	Root = """
		{id} /* {target} */ = {
			isa = {isa};
			buildActionMask = 2147483647;
			files = (
{files}
			);
			runOnlyForDeploymentPostprocessing = 0;
		};
"""

# class SourceBuildPhase
class SourceBuildPhase( BuildPhase ):
	# ctor
	def __init__( self, target ):
		BuildPhase.__init__( self, 'PBXSourcesBuildPhase', target, 'Sources' )

# class FrameworkBuildPhase
class FrameworkBuildPhase( BuildPhase ):
	# ctor
	def __init__( self, target ):
		BuildPhase.__init__( self, 'PBXFrameworksBuildPhase', target, 'Frameworks' )

# class ResourceBuildPhase
class ResourceBuildPhase( BuildPhase ):
	# ctor
	def __init__( self, target ):
		BuildPhase.__init__( self, 'PBXResourcesBuildPhase', target, 'Resources' )

# class ShellScriptPhase
class ShellScriptPhase( BuildPhase ):
	# ctor
	def __init__( self, target, command ):
		BuildPhase.__init__( self, 'PBXShellScriptBuildPhase', target, 'Shell Script' )

		self.command = command

	# compile
	def compile( self ):
		return Template( ShellScriptPhase.Root ).compile( { 'id': self.id, 'isa': self.isa, 'target': self.target.name, 'command': self.command, 'name': self.name } )

	# Root
	Root = """
		{id} /* {target} */ = {
			isa = {isa};
			buildActionMask = 2147483647;
			files = (
			);
			name = "{name}";
			runOnlyForDeploymentPostprocessing = 0;
			shellPath = /bin/sh;
			shellScript = "{command}";
			showEnvVarsInLog = 0;
		};
"""